@@ -16,9 +16,9 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id: build-defs.h.in,v 1.15.2.2.2.2 2007/07/15 15:10:04 jani Exp $ */
+/* $Id: build-defs.h.in 292156 2009-12-15 11:17:47Z jani $ */
 
-#define CONFIGURE_COMMAND " './configure'  '--with-apxs=/usr/sbin/apxs' '--without-mysql' '--enable-xml' '--enable-wddx' '--enable-cli' '--with-iconv=/usr/local' '--with-gettext=/usr/local' '--enable-bcmath' '--enable-session' '--enable-calendar' '--enable-ctype' '--enable-ftp' '--with-pcre-regex' '--enable-sockets' '--enable-sysvsem' '--enable-sysvshm' '--enable-exif' '--without-sqlite' '--without-pdo-sqlite' '--with-pear=/usr/local/share/php5' '--enable-fastcgi' '--enable-force-cgi-redirect' '--with-config-file-scan-dir=/var/www/conf/php5' '--enable-shared' '--disable-static' '--disable-rpath' '--with-config-file-path=/var/www/conf' '--enable-inline-optimization' '--with-pic' '--with-openssl' '--with-zlib' '--enable-suhosin' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info'"
+#define CONFIGURE_COMMAND " './configure'  '--with-apxs=/usr/sbin/apxs' '--without-mysql' '--enable-xml' '--enable-wddx' '--enable-cli' '--with-iconv=/usr/local' '--with-gettext=/usr/local' '--enable-bcmath' '--enable-session' '--enable-calendar' '--enable-ctype' '--enable-ftp' '--with-pcre-regex' '--enable-sockets' '--enable-sysvmsg' '--enable-sysvsem' '--enable-sysvshm' '--enable-exif' '--enable-zend-multibyte' '--without-sqlite' '--without-pdo-sqlite' '--with-pear=/usr/local/share/php5' '--enable-fastcgi' '--enable-force-cgi-redirect' '--with-config-file-scan-dir=/var/www/conf/php5' '--enable-shared' '--disable-static' '--disable-rpath' '--with-config-file-path=/var/www/conf' '--enable-inline-optimization' '--with-pic' '--with-openssl' '--with-zlib' '--enable-suhosin' '--prefix=/usr/local' '--sysconfdir=/etc' '--mandir=/usr/local/man' '--infodir=/usr/local/info'"
 #define PHP_ADA_INCLUDE		""
 #define PHP_ADA_LFLAGS		""
 #define PHP_ADA_LIBS		""
@@ -80,6 +80,7 @@
 #define PHP_EXTENSION_DIR       "/var/www/lib/php/modules"
 #define PHP_PREFIX              "/usr/local"
 #define PHP_BINDIR              "/usr/local/bin"
+#define PHP_SBINDIR             "/usr/local/sbin"
 #define PHP_LIBDIR              "/usr/local/lib/php"
 #define PHP_DATADIR             "/usr/local/share/php"
 #define PHP_SYSCONFDIR          "/etc"
